package application;
	
import javafx.application.Application;
import javafx.scene.Scene;
import javafx.stage.Stage;

/**
 * 
 * @author Lorenz Schauer
 * 
 * Hauptklasse fr das Model-View-Controller Beispiel MIT Verwendung des Observer-Pattern.
 * 
 * Anwendung erzeugt wieder 2 parallele Fenster, die das gleiche Model besitzen. Die Anzeige wird jetzt synchron aktualisiert ber die 
 * Update-Methode der Observer.
 *
 */
public class Main extends Application {
	@Override
	public void start(Stage primaryStage) {
		try {
			
			// Unser Model ist nun auch ein Subjekt (erbt von Observable)
			Bank b = new Bank(100);
			
			// Unsere View ist nun auch ein Beobachter (implementiert das IFace Observer)
			Anzeige anzeige1 = new Anzeige(b);
			Anzeige anzeige2 = new Anzeige(b);
			
			
			// WICHTIG: Dem Subjekt die Beobachter anfgen!
			b.addObserver(anzeige1);
			b.addObserver(anzeige2);
			
			// Sonsnt bleibt hier alles gleich. 
			Scene s1 = new Scene(anzeige1);
			Scene s2 = new Scene(anzeige2);
			
			primaryStage.setScene(s1);
			primaryStage.show();
			
			Stage secondStage = new Stage();
			secondStage.setScene(s2);
			
			secondStage.show();
			
			
		} catch(Exception e) {
			e.printStackTrace();
		}
	}
	
	public static void main(String[] args) {
		launch(args);
	}
}
